@@ -16,6 +16,12 @@
 
 */
 
+#include <osmium/handler.hpp>
+#include <osmium/handler/node_locations_for_ways.hpp>
+#include <osmium/index/map/all.hpp>
+#include <osmium/io/any_input.hpp>
+#include <osmium/visitor.hpp>
+
 #include <algorithm>
 #include <chrono>
 #include <cmath>
@@ -24,13 +30,6 @@
 #include <limits>
 #include <string>
 
-#include <osmium/index/map/all.hpp>
-#include <osmium/handler/node_locations_for_ways.hpp>
-#include <osmium/visitor.hpp>
-
-#include <osmium/io/any_input.hpp>
-#include <osmium/handler.hpp>
-
 using static_index_type = osmium::index::map::SparseMemArray<osmium::unsigned_object_id_type, osmium::Location>;
 const std::string location_store{"sparse_mem_array"};
 
@@ -51,7 +50,7 @@ int main(int argc, char* argv[]) {
 
     const auto& map_factory = osmium::index::MapFactory<osmium::unsigned_object_id_type, osmium::Location>::instance();
 
-    const auto buffer_size = buffer.committed() / (1024*1024); // buffer size in MBytes
+    const auto buffer_size = buffer.committed() / (1024 * 1024); // buffer size in MBytes
     const int runs = std::max(10, static_cast<int>(5000ull / buffer_size));
 
     std::cout << "input: filename=" << input_filename << " buffer_size=" << buffer_size << "MBytes\n";
@@ -82,10 +81,14 @@ int main(int argc, char* argv[]) {
             osmium::apply(tmp_buffer, static_location_handler);
             const auto end = std::chrono::steady_clock::now();
 
-            const double duration = std::chrono::duration<double, std::milli>(end-start).count();
+            const double duration = std::chrono::duration<double, std::milli>(end - start).count();
 
-            if (duration < static_min) static_min = duration;
-            if (duration > static_max) static_max = duration;
+            if (duration < static_min) {
+                static_min = duration;
+            }
+            if (duration > static_max) {
+                static_max = duration;
+            }
             static_sum += duration;
         }
 
@@ -105,16 +108,20 @@ int main(int argc, char* argv[]) {
             osmium::apply(tmp_buffer, dynamic_location_handler);
             const auto end = std::chrono::steady_clock::now();
 
-            const double duration = std::chrono::duration<double, std::milli>(end-start).count();
+            const double duration = std::chrono::duration<double, std::milli>(end - start).count();
 
-            if (duration < dynamic_min) dynamic_min = duration;
-            if (duration > dynamic_max) dynamic_max = duration;
+            if (duration < dynamic_min) {
+                dynamic_min = duration;
+            }
+            if (duration > dynamic_max) {
+                dynamic_max = duration;
+            }
             dynamic_sum += duration;
         }
     }
 
-    const double static_avg = static_sum/runs;
-    const double dynamic_avg = dynamic_sum/runs;
+    const double static_avg = static_sum / runs;
+    const double dynamic_avg = dynamic_sum / runs;
 
     std::cout << "static  min=" << static_min << "ms avg=" << static_avg << "ms max=" << static_max << "ms\n";
     std::cout << "dynamic min=" << dynamic_min << "ms avg=" << dynamic_avg << "ms max=" << dynamic_max << "ms\n";
