@@ -5,11 +5,13 @@
 
 #include "catch.hpp"
 
-#include <osmium/geom/mercator_projection.hpp>
-
 #include "area_helper.hpp"
 #include "wnl_helper.hpp"
 
+#include <osmium/geom/mercator_projection.hpp>
+
+#include <memory>
+
 TEST_CASE("GEOS geometry factory - create point") {
     osmium::geom::GEOSFactory<> factory;
 
@@ -93,7 +95,7 @@ TEST_CASE("GEOS geometry factory - create area with one outer and no inner rings
     const std::unique_ptr<geos::geom::MultiPolygon> mp{factory.create_multipolygon(area)};
     REQUIRE(1 == mp->getNumGeometries());
 
-    const geos::geom::Polygon* p0 = dynamic_cast<const geos::geom::Polygon*>(mp->getGeometryN(0));
+    const auto* p0 = dynamic_cast<const geos::geom::Polygon*>(mp->getGeometryN(0));
     REQUIRE(p0);
     REQUIRE(0 == p0->getNumInteriorRing());
 
@@ -113,7 +115,7 @@ TEST_CASE("GEOS geometry factory - create area with one outer and one inner ring
     const std::unique_ptr<geos::geom::MultiPolygon> mp{factory.create_multipolygon(area)};
     REQUIRE(1 == mp->getNumGeometries());
 
-    const geos::geom::Polygon* p0 = dynamic_cast<const geos::geom::Polygon*>(mp->getGeometryN(0));
+    const auto* p0 = dynamic_cast<const geos::geom::Polygon*>(mp->getGeometryN(0));
     REQUIRE(p0);
     REQUIRE(1 == p0->getNumInteriorRing());
 
@@ -133,14 +135,14 @@ TEST_CASE("GEOS geometry factory - create area with two outer and two inner ring
     const std::unique_ptr<geos::geom::MultiPolygon> mp{factory.create_multipolygon(area)};
     REQUIRE(2 == mp->getNumGeometries());
 
-    const geos::geom::Polygon* p0 = dynamic_cast<const geos::geom::Polygon*>(mp->getGeometryN(0));
+    const auto* p0 = dynamic_cast<const geos::geom::Polygon*>(mp->getGeometryN(0));
     REQUIRE(p0);
     REQUIRE(2 == p0->getNumInteriorRing());
 
     const geos::geom::LineString* l0e = p0->getExteriorRing();
     REQUIRE(5 == l0e->getNumPoints());
 
-    const geos::geom::Polygon* p1 = dynamic_cast<const geos::geom::Polygon*>(mp->getGeometryN(1));
+    const auto* p1 = dynamic_cast<const geos::geom::Polygon*>(mp->getGeometryN(1));
     REQUIRE(p1);
     REQUIRE(0 == p1->getNumInteriorRing());
 
